#!/usr/bin/env bash
set -euo pipefail
IFS=$'\n\t'

# shellcheck source=src/bin/mosaic-common.bash
source "$(dirname "${BASH_SOURCE[0]}")/mosaic-common.bash"

function do_action {
  local action="$1"
  local directory="$2"
  local script="$3"
  declare -a invoke

  echo "Checking dir ${directory}/${script}"
  if [ -d "${directory}/${script}" ]; then
    invoke=("mosaic-${script}.bash" '-v' "${action}" "${directory}/${script}")
    if [ -z "${verbose}" ]; then
      unset "invoke[1]"
    fi
    if_verbose "${invoke[@]}"
  fi
}

if [ "${MOSAIC_USE_TF13-false}" = "true" ]; then
  export PATH=/usr/local/bin/terraform13/:$PATH
fi

# Use all Helm 3 dependencies when flag is set to true
if [ "${ENABLE_HELM3-false}" = "true" ]; then
  export PATH=/usr/local/bin/helm3/:/usr/local/bin/helmsman3/:$PATH
fi

# If this is set to true things fail - ignore env settings.
unset HELM_TLS_VERIFY

mosaic-configure.bash
unset_AWS_env_creds
parse_args "$@"

scripts=(terraform kubernetes helm )

# Destroy terraform last
if [ "${action}" = "destroy" ]; then
  scripts=(kubernetes helm terraform)
fi

for script in "${scripts[@]}"; do
  do_action "${action}" "${directory}" "${script}"
done
